pub enum BudgetExhausted {
ClassExceeded {
attempted: ComplexityClass,
ceiling: ComplexityClass,
},
OpsExhausted {
worst_seen: Option<ComplexityClass>,
},
}Expand description
Reason a try_consume was rejected.
Variants
ClassExceeded
The attempted op’s class is stronger than the budget’s max_class
ceiling. The op was not counted against the remaining ops.
OpsExhausted
The remaining op-count dropped to zero. worst_seen reports
the highest class consumed before the budget ran out.
Fields

worst_seen: Option<ComplexityClass>Trait Implementations
Sourceimpl Clone for BudgetExhausted
impl Clone for BudgetExhausted
Sourcefn clone(&self) -> BudgetExhausted
fn clone(&self) -> BudgetExhausted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BudgetExhausted
impl Debug for BudgetExhausted
Sourceimpl Display for BudgetExhausted
impl Display for BudgetExhausted
Sourceimpl Error for BudgetExhausted
Available on crate features std only.
impl Error for BudgetExhausted
Available on crate features
std only.1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for BudgetExhausted
impl PartialEq for BudgetExhausted
Sourcefn eq(&self, other: &BudgetExhausted) -> bool
fn eq(&self, other: &BudgetExhausted) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BudgetExhausted
impl StructuralPartialEq for BudgetExhausted